Unified Judicial System of Pennsylvania: Commonwealth Court Opinions

http://www.pacourts.us/assets/rss/CommonwealthOpinionsRss.ashx Unified Judicial System of Pennsylvania: Commonwealth Court Opinions Wed, 12 Aug 2015 04:00:00 GMT en-us R. Carpenter v. WCAB (Commonwealth of PA) - 2357 C.D. 2014 http://www.pacourts.us/assets/opinions/Commonwealth/out/2357CD14_8-12-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/2357CD14_8-12-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/2357CD14_8-12-15.pdf Wed, 12 Aug 2015 04:00:00 GMT Colins, Senior Judge K. Hinnershitz and M. Torres-Columbo v. DPW - 1977 C.D. 2014 http://www.pacourts.us/assets/opinions/Commonwealth/out/1977CD14_8-12-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/1977CD14_8-12-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/1977CD14_8-12-15.pdf Wed, 12 Aug 2015 04:00:00 GMT Brobson, J. R. Argro v. WCAB (Ardmore Automotive, Inc.) - 1954 C.D. 2014 http://www.pacourts.us/assets/opinions/Commonwealth/out/1954CD14_8-12-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/1954CD14_8-12-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/1954CD14_8-12-15.pdf Wed, 12 Aug 2015 04:00:00 GMT Brobson, J. Office of the Governor v. R.H. Davis, Jr. - 1940 C.D. 2014 http://www.pacourts.us/assets/opinions/Commonwealth/out/1940CD14_8-12-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/1940CD14_8-12-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/1940CD14_8-12-15.pdf Wed, 12 Aug 2015 04:00:00 GMT Simpson, J. J. Pilchesky v. Mayor William Courtright, et al. - 38 C.D. 2015 http://www.pacourts.us/assets/opinions/Commonwealth/out/38CD15_8-11-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/38CD15_8-11-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/38CD15_8-11-15.pdf Tue, 11 Aug 2015 04:00:00 GMT Friedman, Senior Judge J.M. Faatz v. UCBR - 377 C.D. 2015 http://www.pacourts.us/assets/opinions/Commonwealth/out/377CD15_8-11-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/377CD15_8-11-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/377CD15_8-11-15.pdf Tue, 11 Aug 2015 04:00:00 GMT McGinley, J. Minuteman Spill Response, Inc. v. UCBR - 42 C.D. 2015 http://www.pacourts.us/assets/opinions/Commonwealth/out/42CD15_8-11-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/42CD15_8-11-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/42CD15_8-11-15.pdf Tue, 11 Aug 2015 04:00:00 GMT McGinley, J. A.R. Wilson v. PA BPP - 329 C.D. 2015 http://www.pacourts.us/assets/opinions/Commonwealth/out/329CD15_8-11-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/329CD15_8-11-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/329CD15_8-11-15.pdf Tue, 11 Aug 2015 04:00:00 GMT Pellegrini, President Judge SEPTA v. City of Philadelphia and Philadelphia Commission on Human Relations - 2445 C.D. 2009 http://www.pacourts.us/assets/opinions/Commonwealth/out/2445CD09_8-7-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/2445CD09_8-7-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/2445CD09_8-7-15.pdf Fri, 07 Aug 2015 04:00:00 GMT Leavitt, J. ~ Dissenting Opinions by Pellegrini, President Judge and Simpson, J. City of Allentown v. IAFF Local 302 - 1802 C.D. 2014 http://www.pacourts.us/assets/opinions/Commonwealth/out/1802CD14_8-7-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/1802CD14_8-7-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/1802CD14_8-7-15.pdf Fri, 07 Aug 2015 04:00:00 GMT Pellegrini, President Judge ~ Dissenting Opinions by Brobson and McCullough, JJ. D.D. Colbert v. PA BPP - 2376 C.D. 2014 http://www.pacourts.us/assets/opinions/Commonwealth/out/2376CD14_8-6-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/2376CD14_8-6-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/2376CD14_8-6-15.pdf Thu, 06 Aug 2015 04:00:00 GMT Simpson, J. E. Miller v. UCBR - 1689 C.D. 2014 http://www.pacourts.us/assets/opinions/Commonwealth/out/1689CD14_8-6-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/1689CD14_8-6-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/1689CD14_8-6-15.pdf Thu, 06 Aug 2015 04:00:00 GMT Simpson, J. C. Riddick v. PA BPP - 1250 C.D. 2014 http://www.pacourts.us/assets/opinions/Commonwealth/out/1250CD14_8-6-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/1250CD14_8-6-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/1250CD14_8-6-15.pdf Thu, 06 Aug 2015 04:00:00 GMT Leadbetter, J. R. Soose v. WCAB (PSC Metals, Inc.) - 549 C.D. 2014 http://www.pacourts.us/assets/opinions/Commonwealth/out/549CD14_8-6-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/549CD14_8-6-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/549CD14_8-6-15.pdf Thu, 06 Aug 2015 04:00:00 GMT Leadbetter, J. M.P. Dec v. Butler, PA. Clerk of Courts - 271 C.D. 2015 http://www.pacourts.us/assets/opinions/Commonwealth/out/271CD15_8-6-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/271CD15_8-6-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/271CD15_8-6-15.pdf Thu, 06 Aug 2015 04:00:00 GMT McGinley, J. J.D. Schneller v. Clerk of Orphans' Court of Chester County, et al. - 1901 C.D. 2014 http://www.pacourts.us/assets/opinions/Commonwealth/out/1901CD14_8-5-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/1901CD14_8-5-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/1901CD14_8-5-15.pdf Wed, 05 Aug 2015 04:00:00 GMT PER CURIAM Eastern Logistics, Inc. v. WCAB (Jenkins) - 255 C.D. 2015 http://www.pacourts.us/assets/opinions/Commonwealth/out/255CD15_8-5-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/255CD15_8-5-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/255CD15_8-5-15.pdf Wed, 05 Aug 2015 04:00:00 GMT Friedman, Senior Judge Amazon.com v. WCAB (Davidson) - 1828 C.D. 2014 http://www.pacourts.us/assets/opinions/Commonwealth/out/1828CD14_8-5-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/1828CD14_8-5-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/1828CD14_8-5-15.pdf Wed, 05 Aug 2015 04:00:00 GMT McCullough, J. L. Zhang v. WCAB (Penn State Milton S. Hershey MC and Inservco Ins. Svcs.) - 2151 C.D. 2014 http://www.pacourts.us/assets/opinions/Commonwealth/out/2151CD14_8-5-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/2151CD14_8-5-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/2151CD14_8-5-15.pdf Wed, 05 Aug 2015 04:00:00 GMT Brobson, J. Advanced Dermatology Associates (Selective Insurance Company of America) v. WCAB (Bunce) - 2186 C.D. 2014 http://www.pacourts.us/assets/opinions/Commonwealth/out/2186CD14_8-5-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/2186CD14_8-5-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/2186CD14_8-5-15.pdf Wed, 05 Aug 2015 04:00:00 GMT Leavitt, J. J. Cicchiello v. DOC - 83 C.D. 2015 http://www.pacourts.us/assets/opinions/Commonwealth/out/83CD15_8-5-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/83CD15_8-5-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/83CD15_8-5-15.pdf Wed, 05 Aug 2015 04:00:00 GMT Cohn Jubelirer, J. Philadelphia Corporation for Aging v. UCBR - 11 C.D. 2015 http://www.pacourts.us/assets/opinions/Commonwealth/out/11CD15_8-5-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/11CD15_8-5-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/11CD15_8-5-15.pdf Wed, 05 Aug 2015 04:00:00 GMT Cohn Jubelirer, J. L. Evans v. PA BPP - 2300 C.D. 2014 http://www.pacourts.us/assets/opinions/Commonwealth/out/2300CD14_8-5-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/2300CD14_8-5-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/2300CD14_8-5-15.pdf Wed, 05 Aug 2015 04:00:00 GMT Cohn Jubelirer, J. D.A. Titus v. PSP - 1841 C.D. 2014 http://www.pacourts.us/assets/opinions/Commonwealth/out/1841CD14_8-5-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/1841CD14_8-5-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/1841CD14_8-5-15.pdf Wed, 05 Aug 2015 04:00:00 GMT Cohn Jubelirer, J. N.L. Hufford, et al. v. East Cocalico Twp. ZHB ~ Appeal of: N.L. Hufford - 1973 C.D. 2014 http://www.pacourts.us/assets/opinions/Commonwealth/out/1973CD14_8-5-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/1973CD14_8-5-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/1973CD14_8-5-15.pdf Wed, 05 Aug 2015 04:00:00 GMT Pellegrini, President Judge J.O. Lozado v. WCAB (Dependable Concrete Work and UEGF) - 21 C.D. 2014 http://www.pacourts.us/assets/opinions/Commonwealth/out/21CD14_8-5-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/21CD14_8-5-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/21CD14_8-5-15.pdf Wed, 05 Aug 2015 04:00:00 GMT Cohn Jubelirer, J. J. Mills v. PennDOT, Bureau of Driver Licensing - 88 C.D. 2015 http://www.pacourts.us/assets/opinions/Commonwealth/out/88CD15_8-4-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/88CD15_8-4-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/88CD15_8-4-15.pdf Tue, 04 Aug 2015 04:00:00 GMT McCullough, J. D. Mitchell v. UCBR - 2199 C.D. 2014 http://www.pacourts.us/assets/opinions/Commonwealth/out/2199CD14_8-4-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/2199CD14_8-4-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/2199CD14_8-4-15.pdf Tue, 04 Aug 2015 04:00:00 GMT McCullough, J. The Shadowfax Corporation v. UCBR - 2121 C.D. 2014 http://www.pacourts.us/assets/opinions/Commonwealth/out/2121CD14_8-4-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/2121CD14_8-4-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/2121CD14_8-4-15.pdf Tue, 04 Aug 2015 04:00:00 GMT McCullough, J. B. Jenkins v. City of Philadelphia - 1470 C.D. 2014 http://www.pacourts.us/assets/opinions/Commonwealth/out/1470CD14_8-3-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/1470CD14_8-3-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/1470CD14_8-3-15.pdf Mon, 03 Aug 2015 04:00:00 GMT Leadbetter, J. R.C. Cioppa and M. Cioppa v. SERS - 1219 C.D. 2014 http://www.pacourts.us/assets/opinions/Commonwealth/out/1219CD14_8-3-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/1219CD14_8-3-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/1219CD14_8-3-15.pdf Mon, 03 Aug 2015 04:00:00 GMT Leadbetter, J. ~ Concurring and Dissenting Opinion by Colins, Senior Judge A.B. Beers v. UCBR - 380 C.D. 2015 http://www.pacourts.us/assets/opinions/Commonwealth/out/380CD15_8-3-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/380CD15_8-3-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/380CD15_8-3-15.pdf Mon, 03 Aug 2015 04:00:00 GMT McGinley, J. E. Horan v. WCAB (Phoebe Home) - 1868 C.D. 2014 http://www.pacourts.us/assets/opinions/Commonwealth/out/1868CD14_8-3-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/1868CD14_8-3-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/1868CD14_8-3-15.pdf Mon, 03 Aug 2015 04:00:00 GMT McGinley, J. ~ Concurring Opinion by Brobson, J. A. Dillard v. UCBR - 2010 C.D. 2014 http://www.pacourts.us/assets/opinions/Commonwealth/out/2010CD14_7-31-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/2010CD14_7-31-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/2010CD14_7-31-15.pdf Fri, 31 Jul 2015 04:00:00 GMT Colins, Senior Judge A.P. Ippolito v. UCBR - 1969 C.D. 2014 http://www.pacourts.us/assets/opinions/Commonwealth/out/1969CD14_7-31-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/1969CD14_7-31-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/1969CD14_7-31-15.pdf Fri, 31 Jul 2015 04:00:00 GMT Colins, Senior Judge R.M. Russella v. PennDOT, Bureau of Driver Licensing - 1885 C.D. 2014 http://www.pacourts.us/assets/opinions/Commonwealth/out/1885CD14_7-31-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/1885CD14_7-31-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/1885CD14_7-31-15.pdf Fri, 31 Jul 2015 04:00:00 GMT Colins, Senior Judge I. Gonzalez v. WCAB (J.D. Eckman, Inc., and Travelers Property Casualty Company of America) - 1806 C.D. 2014 http://www.pacourts.us/assets/opinions/Commonwealth/out/1806CD14_7-31-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/1806CD14_7-31-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/1806CD14_7-31-15.pdf Fri, 31 Jul 2015 04:00:00 GMT Covey, J. Laymen's Retreat League v. UCBR - 777 C.D. 2014 http://www.pacourts.us/assets/opinions/Commonwealth/out/777CD14_7-31-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/777CD14_7-31-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/777CD14_7-31-15.pdf Fri, 31 Jul 2015 04:00:00 GMT Covey, J. L. Edwards v. UCBR - 2150 C.D. 2014 http://www.pacourts.us/assets/opinions/Commonwealth/out/2150CD14_7-31-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/2150CD14_7-31-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/2150CD14_7-31-15.pdf Fri, 31 Jul 2015 04:00:00 GMT McCullough, J. J.R. Reviello, Jr. v. UCBR - 2315 C.D. 2014 http://www.pacourts.us/assets/opinions/Commonwealth/out/2315CD14_7-31-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/2315CD14_7-31-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/2315CD14_7-31-15.pdf Fri, 31 Jul 2015 04:00:00 GMT Simpson, J. The Buonarroti Trust v. City of Harrisburg Department of Building and Housing Development, Bureau of Codes Enforcement - 1637 C.D. 2014 http://www.pacourts.us/assets/opinions/Commonwealth/out/1637CD14_7-31-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/1637CD14_7-31-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/1637CD14_7-31-15.pdf Fri, 31 Jul 2015 04:00:00 GMT Simpson, J. K.H. Adley v. UCBR - 2331 C.D. 2014 http://www.pacourts.us/assets/opinions/Commonwealth/out/2331CD14_7-31-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/2331CD14_7-31-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/2331CD14_7-31-15.pdf Fri, 31 Jul 2015 04:00:00 GMT Cohn Jubelirer, J. Valley Forge Sewer Authority v. B. Hipwell, et al. - 1924 C.D. 2013 http://www.pacourts.us/assets/opinions/Commonwealth/out/1924CD13_7-31-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/1924CD13_7-31-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/1924CD13_7-31-15.pdf Fri, 31 Jul 2015 04:00:00 GMT Covey, J. Estate of G. Deckard, D.I. Grunfeld, Admin. Ad Litem, t/a Beer Hut v. PLCB - 2091 C.D. 2014 http://www.pacourts.us/assets/opinions/Commonwealth/out/2091CD14_7-31-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/2091CD14_7-31-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/2091CD14_7-31-15.pdf Fri, 31 Jul 2015 04:00:00 GMT McCullough, J. Malt Beverage Distributors Association, et al. v. PLCB - 1352 C.D. 2014 http://www.pacourts.us/assets/opinions/Commonwealth/out/1352CD14_7-31-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/1352CD14_7-31-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/1352CD14_7-31-15.pdf Fri, 31 Jul 2015 04:00:00 GMT McCullough, J. C.M. Dusman v. The Board of Directors of the Chambersburg Area SD and The Chambersburg Area SD - 924 and 974 C.D. 2014 http://www.pacourts.us/assets/opinions/Commonwealth/out/924CD14_7-31-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/924CD14_7-31-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/924CD14_7-31-15.pdf Fri, 31 Jul 2015 04:00:00 GMT Brobson, J. J. McWells v. UCBR - 2208 C.D. 2014 http://www.pacourts.us/assets/opinions/Commonwealth/out/2208CD14_7-30-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/2208CD14_7-30-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/2208CD14_7-30-15.pdf Thu, 30 Jul 2015 04:00:00 GMT Covey, J. B. Cruthers v. PA BPP - 1950 C.D. 2014 http://www.pacourts.us/assets/opinions/Commonwealth/out/1950CD14_7-30-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/1950CD14_7-30-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/1950CD14_7-30-15.pdf Thu, 30 Jul 2015 04:00:00 GMT Covey, J. J. Smale v. WCAB (Dana Corp. Torque Traction M) - 696 C.D. 2014 http://www.pacourts.us/assets/opinions/Commonwealth/out/696CD14_7-30-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/696CD14_7-30-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/696CD14_7-30-15.pdf Thu, 30 Jul 2015 04:00:00 GMT Covey, J. M.A. Steinberg, D.D.S. v. DOS, BPOA, State Board of Dentistry - 164 C.D. 2015 http://www.pacourts.us/assets/opinions/Commonwealth/out/164CD15_7-30-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/164CD15_7-30-15.pdf http://www.pacourts.us/assets/opinions/Commonwealth/out/164CD15_7-30-15.pdf Thu, 30 Jul 2015 04:00:00 GMT Brobson, J.